Introduction
============

Map widget for ``z3c.form`` based on ``collective.geo.mapwidget``.

For more information about ``collective.geo``, see the `Coactivate home page
<https://www.coactivate.org/projects/collectivegeo/>`_.

Installation
============

This addon can be installed in the same manner as other addons; please follow
the official `Plone documentation`_.

Usage
=====

In order to use the widget contained in this package, use
``collective.z3cform.mapwidget.widget.MapFieldWidget`` and set this as
the widget for a suitable field within your form schema. One such suitable
field type is that of ``zope.schema.TextLine``.

.. _Plone documentation: https://docs.plone.org/manage/installing/installing_addons.html
